Address class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Address({String? country, String? postalCode, String? addressLine1, String? addressLine2, String? addressLine3, String? administrativeDistrictLevel1, String? locality, String? sublocality})
Address.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 → String?
final
addressLine2 → String?
final
addressLine3 → String?
final
administrativeDistrictLevel1 → String?
final
country → String?
final
hashCode → int
The hash code for this object.
no setterinherited
locality → String?
final
postalCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sublocality → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited