AppointmentSegment class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

AppointmentSegment({String? teamMemberId, bool? anyTeamMember, int? durationMinutes, int? intermissionMinutes, List<String>? resourceIds, int? serviceVariationId, String? serviceVariationVersion})
AppointmentSegment.fromJson(Map<String, dynamic> json)
factory

Properties

anyTeamMember → bool?
final
durationMinutes → int?
final
hashCode → int
The hash code for this object.
no setterinherited
intermissionMinutes → int?
final
resourceIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceVariationId → int?
final
serviceVariationVersion → String?
final
teamMemberId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited