BankAccount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BankAccount({String? id, int? version, BankAccountStatus? status, String? locationId, String? referenceId, String? country, String? currency, String? fingerprint, BankAccountType? accountType, String? accountNumberSuffix, String? bankName, bool? creditable, bool? debitable, String? debitMandateReferenceId, String? holderName, String? primaryBankIdentificationNumber, String? secondaryBankIdentificationNumber})
BankAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumberSuffix → String?
final
accountType → BankAccountType?
final
bankName → String?
final
country → String?
final
creditable → bool?
final
currency → String?
final
debitable → bool?
final
debitMandateReferenceId → String?
final
fingerprint → String?
final
hashCode → int
The hash code for this object.
no setterinherited
holderName → String?
final
id → String?
final
locationId → String?
final
primaryBankIdentificationNumber → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryBankIdentificationNumber → String?
final
status → BankAccountStatus?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited