BankAccountPaymentDetails class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BankAccountPaymentDetails({String? statementDescription, List<SquareError>? errors, String? bankName, String? fingerprint, String? country, String? accountOwnershipType, ACHDetails? achDetails, TransferType? transferType})
BankAccountPaymentDetails.fromJson(Map<String, dynamic> json)
factory

Properties

accountOwnershipType → String?
final
achDetails → ACHDetails?
final
bankName → String?
final
country → String?
final
errors → List<SquareError>?
final
fingerprint → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementDescription → String?
final
transferType → TransferType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited