BatchInventoryChangeRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BatchInventoryChangeRequest({required String idempotencyKey, List<InventoryChange>? changes, bool? ignoreUnchangedCounts})
BatchInventoryChangeRequest.fromJson(Map<String, dynamic> json)
factory

Properties

changes → List<InventoryChange>?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
ignoreUnchangedCounts → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited