BatchInventoryReadRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BatchInventoryReadRequest({String? cursor, List<String>? locationIds, List<String>? catalogObjectIds, List<InventoryState>? states, List<InventoryChangeType>? types, String? updatedAfter, String? updatedBefore})
BatchInventoryReadRequest.fromJson(Map<String, dynamic> json)
factory

Properties

catalogObjectIds → List<String>?
final
cursor → String?
final
hashCode → int
The hash code for this object.
no setterinherited
locationIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
states → List<InventoryState>?
final
types → List<InventoryChangeType>?
final
updatedAfter → String?
final
updatedBefore → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited