Break class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Break({String? id, String? endAt, String? startAt, bool? isPaid, String? expectedDuration, String? name, String? breakTypeId})
Break.fromJson(Map<String, dynamic> json)
factory

Properties

breakTypeId → String?
final
endAt → String?
final
expectedDuration → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isPaid → bool?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited