BreakTypeResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BreakTypeResponse({String? cursor, List<BreakType>? breakTypes, List<SquareError>? errors, BreakType? breakType})
BreakTypeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

breakType → BreakType?
final
breakTypes → List<BreakType>?
final
cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited