BusinessBookingProfile class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BusinessBookingProfile({String? createdAt, bool? allowUserCancel, bool? bookingEnabled, BusinessBookingProfileBookingPolicy? bookingPolicy, BusinessAppointmentSettings? businessAppointmentSettings, BusinessBookingProfileCustomerTimezoneChoice? customerTimezoneChoice, String? sellerId})
BusinessBookingProfile.fromJson(Map<String, dynamic> json)
factory

Properties

allowUserCancel → bool?
final
bookingEnabled → bool?
final
bookingPolicy → BusinessBookingProfileBookingPolicy?
final
businessAppointmentSettings → BusinessAppointmentSettings?
final
createdAt → String?
final
customerTimezoneChoice → BusinessBookingProfileCustomerTimezoneChoice?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited