Card class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Card({String? customerId, String? id, int? version, String? referenceId, String? merchantId, int? expYear, int? expMonth, CardType? cardType, Address? billingAddress, String? bin, CardBrand? cardBrand, String? cardholderName, bool? enabled, String? fingerprint, String? last4, CardPrepaidType? prepaidType})
Card.fromJson(Map<String, dynamic> json)
factory

Properties

billingAddress → Address?
final
bin → String?
final
cardBrand → CardBrand?
final
cardholderName → String?
final
cardType → CardType?
final
customerId → String?
final
enabled → bool?
final
expMonth → int?
final
expYear → int?
final
fingerprint → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
last4 → String?
final
merchantId → String?
final
prepaidType → CardPrepaidType?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited