CashDrawerShiftEvent class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CashDrawerShiftEvent({String? description, String? id, String? createdAt, String? employeeId, Money? eventMoney, CashDrawerEventType? eventType})
CashDrawerShiftEvent.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
description → String?
final
employeeId → String?
final
eventMoney → Money?
final
eventType → CashDrawerEventType?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited