CashPaymentDetails class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CashPaymentDetails({Money? buyerSuppliedMoney, Money? changeBackMoney})
CashPaymentDetails.fromJson(Map<String, dynamic> json)
factory

Properties

buyerSuppliedMoney → Money?
final
changeBackMoney → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited