CatalogCustomAttributeValue class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogCustomAttributeValue({String? name, CatalogCustomAttributeDefinitionType? type, bool? booleanValue, String? stringValue, String? customAttributeDefinitionId, String? key, String? numberValue})
CatalogCustomAttributeValue.fromJson(Map<String, dynamic> json)
factory

Properties

booleanValue → bool?
final
customAttributeDefinitionId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
final
name → String?
final
numberValue → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
final
type → CatalogCustomAttributeDefinitionType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited