CatalogDiscount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogDiscount({String? name, String? labelColor, String? percentage, Money? amountMoney, CatalogDiscountType? discountType, Money? maximumAmountMoney, CatalogDiscountModifyTaxBasis? modifyTaxBasis, bool? pinRequired})
CatalogDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
discountType → CatalogDiscountType?
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → String?
final
maximumAmountMoney → Money?
final
modifyTaxBasis → CatalogDiscountModifyTaxBasis?
final
name → String?
final
percentage → String?
final
pinRequired → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited