CatalogInfoResponseLimits class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogInfoResponseLimits({int? batchDeleteMaxObjectIds, int? batchRetrieveMaxObjectIds, int? batchUpsertMaxObjectsPerBatch, int? batchUpsertMaxTotalObjects, int? searchMaxPageLimit, int? updateItemModifierListsMaxModifierListsToDisable, int? updateItemModifierListsMaxModifierListsToEnable, int? updateItemTaxesMaxTaxesToDisable, int? updateItemTaxesMaxTaxesToEnable})
CatalogInfoResponseLimits.fromJson(Map<String, dynamic> json)
factory

Properties

batchDeleteMaxObjectIds → int?
final
batchRetrieveMaxObjectIds → int?
final
batchUpsertMaxObjectsPerBatch → int?
final
batchUpsertMaxTotalObjects → int?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchMaxPageLimit → int?
final
updateItemModifierListsMaxModifierListsToDisable → int?
final
updateItemModifierListsMaxModifierListsToEnable → int?
final
updateItemTaxesMaxTaxesToDisable → int?
final
updateItemTaxesMaxTaxesToEnable → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited