CatalogItem class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogItem({String? name, String? description, List<String>? imageIds, List<String>? taxIds, String? abbreviation, bool? availableElectronically, bool? availableForPickup, bool? availableOnline, String? categoryId, List<CatalogItemOptionForItem>? itemOptions, String? labelColor, List<CatalogItemModifierListInfo>? modifierListInfo, CatalogItemProductType? productType, bool? skipModifierScreen, String? sortName, List<CatalogObject>? variations})
CatalogItem.fromJson(Map<String, dynamic> json)
factory

Properties

abbreviation → String?
final
availableElectronically → bool?
final
availableForPickup → bool?
final
availableOnline → bool?
final
categoryId → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
imageIds → List<String>?
final
itemOptions → List<CatalogItemOptionForItem>?
final
labelColor → String?
final
modifierListInfo → List<CatalogItemModifierListInfo>?
final
name → String?
final
productType → CatalogItemProductType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipModifierScreen → bool?
final
sortName → String?
final
taxIds → List<String>?
final
variations → List<CatalogObject>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited