CatalogItemModifierListInfo class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogItemModifierListInfo({String? modifierListId, bool? enabled, int? maxSelectedModifiers, int? minSelectedModifiers, List<CatalogModifierOverride>? modifierOverrides})
CatalogItemModifierListInfo.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
maxSelectedModifiers → int?
final
minSelectedModifiers → int?
final
modifierListId → String?
final
modifierOverrides → List<CatalogModifierOverride>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited