CatalogItemVariation class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogItemVariation({Money? priceMoney, String? name, int? ordinal, List<String>? imageIds, String? sku, bool? availableForBooking, int? inventoryAlertThreshold, InventoryAlertType? inventoryAlertType, String? itemId, List<CatalogItemOptionValueForItemVariation>? itemOptionValues, List<ItemVariationLocationOverrides>? locationOverrides, String? measurementUnitId, CatalogPricingType? pricingType, int? serviceDuration, bool? stockable, CatalogStockConversion? stockableConversion, List<String>? teamMemberIds, bool? trackInventory, String? upc, String? userData})
CatalogItemVariation.fromJson(Map<String, dynamic> json)
factory

Properties

availableForBooking → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
imageIds → List<String>?
final
inventoryAlertThreshold → int?
final
inventoryAlertType → InventoryAlertType?
final
itemId → String?
final
itemOptionValues → List<CatalogItemOptionValueForItemVariation>?
final
locationOverrides → List<ItemVariationLocationOverrides>?
final
measurementUnitId → String?
final
name → String?
final
ordinal → int?
final
priceMoney → Money?
final
pricingType → CatalogPricingType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceDuration → int?
final
sku → String?
final
stockable → bool?
final
stockableConversion → CatalogStockConversion?
final
teamMemberIds → List<String>?
final
trackInventory → bool?
final
upc → String?
final
userData → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited