CatalogItemsSearchRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogItemsSearchRequest({int? limit, String? cursor, SortOrder? sortOrder, List<String>? categoryIds, List<CustomAttributeFilter>? customAttributeFilters, List<String>? enabledLocationIds, List<CatalogItemProductType>? productTypes, List<SearchCatalogItemsRequestStockLevel>? stockLevels, String? textFilter})
CatalogItemsSearchRequest.fromJson(Map<String, dynamic> json)
factory

Properties

categoryIds → List<String>?
final
cursor → String?
final
customAttributeFilters → List<CustomAttributeFilter>?
final
enabledLocationIds → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
final
productTypes → List<CatalogItemProductType>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → SortOrder?
final
stockLevels → List<SearchCatalogItemsRequestStockLevel>?
final
textFilter → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited