CatalogMeasurementUnit class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogMeasurementUnit({int? precision, MeasurementUnit? measurementUnit})
CatalogMeasurementUnit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
measurementUnit → MeasurementUnit?
final
precision → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited