CatalogModifier class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogModifier({int? ordinal, String? name, String? modifierListId, Money? priceMoney})
CatalogModifier.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
modifierListId → String?
final
name → String?
final
ordinal → int?
final
priceMoney → Money?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited