CatalogModifierList class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogModifierList({String? name, int? ordinal, List<CatalogObject>? modifiers, List<String>? imageIds, CatalogModifierListSelectionType? selectionType})
CatalogModifierList.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageIds → List<String>?
final
modifiers → List<CatalogObject>?
final
name → String?
final
ordinal → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionType → CatalogModifierListSelectionType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited