CatalogPricingRule class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogPricingRule({String? name, String? applyProductsId, List<String>? customerGroupIdsAny, String? discountId, String? excludeProductsId, ExcludeStrategy? excludeStrategy, String? matchProductsId, Money? minimumOrderSubtotalMoney, List<String>? timePeriodIds, String? validFromDate, String? validFromLocalTime, String? validUntilDate, String? validUntilLocalTime})
CatalogPricingRule.fromJson(Map<String, dynamic> json)
factory

Properties

applyProductsId → String?
final
customerGroupIdsAny → List<String>?
final
discountId → String?
final
excludeProductsId → String?
final
excludeStrategy → ExcludeStrategy?
final
hashCode → int
The hash code for this object.
no setterinherited
matchProductsId → String?
final
minimumOrderSubtotalMoney → Money?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriodIds → List<String>?
final
validFromDate → String?
final
validFromLocalTime → String?
final
validUntilDate → String?
final
validUntilLocalTime → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited