CatalogQuickAmount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogQuickAmount({int? ordinal, CatalogQuickAmountType? type, Money? amount, int? score})
CatalogQuickAmount.fromJson(Map<String, dynamic> json)
factory

Properties

amount → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
ordinal → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → int?
final
type → CatalogQuickAmountType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited