CatalogQuickAmountsSettings class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogQuickAmountsSettings({CatalogQuickAmountsSettingsOption? option, List<CatalogQuickAmount>? amounts, bool? eligibleForAutoAmounts})
CatalogQuickAmountsSettings.fromJson(Map<String, dynamic> json)
factory

Properties

amounts → List<CatalogQuickAmount>?
final
eligibleForAutoAmounts → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
option → CatalogQuickAmountsSettingsOption?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited