CatalogResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogResponse({String? cursor, List<SquareError>? errors, String? latestTime, List<CatalogObject>? objects, List<CatalogObject>? relatedObjects, String? updatedAt, List<CatalogIdMapping>? idMappings, CatalogObject? image, CatalogInfoResponseLimits? limits, StandardUnitDescriptionGroup? standardUnitDescriptionGroup})
CatalogResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
idMappings → List<CatalogIdMapping>?
final
image → CatalogObject?
final
latestTime → String?
final
limits → CatalogInfoResponseLimits?
final
objects → List<CatalogObject>?
final
relatedObjects → List<CatalogObject>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardUnitDescriptionGroup → StandardUnitDescriptionGroup?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited