CatalogSearchRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CatalogSearchRequest({String? cursor, bool? includeRelatedObjects, int? limit, CatalogQuery? query, String? beginTime, bool? includeDeletedObjects, List<String>? objectTypes})
CatalogSearchRequest.fromJson(Map<String, dynamic> json)
factory

Properties

beginTime → String?
final
cursor → String?
final
hashCode → int
The hash code for this object.
no setterinherited
includeDeletedObjects → bool?
final
includeRelatedObjects → bool?
final
limit → int?
final
objectTypes → List<String>?
final
query → CatalogQuery?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited