Checkout class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Checkout({Address? prePopulateShippingAddress, String? prePopulateBuyerEmail, String? merchantSupportEmail, bool? askForShippingAddress, String? redirectUrl, List<AdditionalRecipient>? additionalRecipients, Order? order, String? id, String? createdAt, String? checkoutPageUrl})
Checkout.fromJson(Map<String, dynamic> json)
factory

Properties

additionalRecipients → List<AdditionalRecipient>?
final
askForShippingAddress → bool?
final
checkoutPageUrl → String?
final
createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
merchantSupportEmail → String?
final
order → Order?
final
prePopulateBuyerEmail → String?
final
prePopulateShippingAddress → Address?
final
redirectUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited