CreateCheckoutRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CreateCheckoutRequest({required String idempotencyKey, String? note, CreateOrderRequest? order, List<ChargeRequestAdditionalRecipient>? additionalRecipients, String? redirectUrl, bool? askForShippingAddress, String? merchantSupportEmail, String? prePopulateBuyerEmail, Address? prePopulateShippingAddress})
CreateCheckoutRequest.fromJson(Map<String, dynamic> json)
factory

Properties

additionalRecipients → List<ChargeRequestAdditionalRecipient>?
final
askForShippingAddress → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
merchantSupportEmail → String?
final
note → String?
final
order → CreateOrderRequest?
final
prePopulateBuyerEmail → String?
final
prePopulateShippingAddress → Address?
final
redirectUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited