CreatePaymentRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CreatePaymentRequest({String? locationId, required String sourceId, Money? amountMoney, Money? appFeeMoney, ExternalPaymentDetails? externalDetails, String? delayDuration, Money? tipMoney, String? buyerEmailAddress, CashPaymentDetails? cashDetails, Address? billingAddress, String? referenceId, String? note, String? orderId, String? customerId, String? teamMemberId, required String idempotencyKey, bool? acceptPartialAuthorization, bool? autocomplete, Address? shippingAddress, String? verificationToken})
CreatePaymentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

acceptPartialAuthorization → bool?
final
amountMoney → Money?
final
appFeeMoney → Money?
final
autocomplete → bool?
final
billingAddress → Address?
final
buyerEmailAddress → String?
final
cashDetails → CashPaymentDetails?
final
customerId → String?
final
delayDuration → String?
final
externalDetails → ExternalPaymentDetails?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
locationId → String?
final
note → String?
final
orderId → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress → Address?
final
sourceId → String
final
teamMemberId → String?
final
tipMoney → Money?
final
verificationToken → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited