CreateSubscriptionRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CreateSubscriptionRequest({required String locationId, String? idempotencyKey, required String customerId, String? timezone, SubscriptionSource? source, String? cardId, String? taxPercentage, String? startDate, Money? priceOverrideMoney, String? canceledDate, required String planId})
CreateSubscriptionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

canceledDate → String?
final
cardId → String?
final
customerId → String
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String?
final
locationId → String
final
planId → String
final
priceOverrideMoney → Money?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → SubscriptionSource?
final
startDate → String?
final
taxPercentage → String?
final
timezone → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited