Customer class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Customer({String? id, String? referenceId, String? createdAt, CustomerTaxIds? taxIds, int? version, String? updatedAt, String? familyName, String? givenName, String? companyName, String? phoneNumber, Address? address, String? emailAddress, String? note, CustomerPreferences? preferences, String? birthday, List<Card>? cards, CustomerCreationSource? creationSource, List<String>? groupIds, String? nickname, List<String>? segmentIds})
Customer.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
birthday → String?
final
cards → List<Card>?
final
companyName → String?
final
createdAt → String?
final
creationSource → CustomerCreationSource?
final
emailAddress → String?
final
familyName → String?
final
givenName → String?
final
groupIds → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
nickname → String?
final
note → String?
final
phoneNumber → String?
final
preferences → CustomerPreferences?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentIds → List<String>?
final
taxIds → CustomerTaxIds?
final
updatedAt → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited