CustomerFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CustomerFilter({CustomerTextFilter? referenceId, TimeRange? createdAt, CustomerTextFilter? phoneNumber, CustomerTextFilter? emailAddress, CustomerCreationSourceFilter? creationSource, FilterValue? groupIds, TimeRange? updatedAt})
CustomerFilter.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → TimeRange?
final
creationSource → CustomerCreationSourceFilter?
final
emailAddress → CustomerTextFilter?
final
groupIds → FilterValue?
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → CustomerTextFilter?
final
referenceId → CustomerTextFilter?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → TimeRange?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited