CustomerUpsertRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CustomerUpsertRequest({String? idempotencyKey, String? nickname, String? referenceId, CustomerTaxIds? taxIds, String? familyName, String? givenName, String? companyName, String? phoneNumber, Address? address, String? emailAddress, String? note, String? birthday})
CustomerUpsertRequest.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
birthday → String?
final
companyName → String?
final
emailAddress → String?
final
familyName → String?
final
givenName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String?
final
nickname → String?
final
note → String?
final
phoneNumber → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxIds → CustomerTaxIds?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited