DeviceCode class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

DeviceCode({String? name, String? createdAt, DeviceCodeStatus? status, String? id, String? locationId, ProductType? productType, String? code, String? deviceId, String? pairBy, String? pairedAt, String? statusChangedAt})
DeviceCode.fromJson(Map<String, dynamic> json)
factory

Properties

code → String?
final
createdAt → String?
final
deviceId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
name → String?
final
pairBy → String?
final
pairedAt → String?
final
productType → ProductType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DeviceCodeStatus?
final
statusChangedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited