Dispute class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Dispute({Money? amountMoney, String? id, String? locationId, DisputeReason? reason, String? cardBrand, String? createdAt, String? updatedAt, int? version, DisputeState? state, String? brandDisputeId, DisputedPayment? disputedPayment, String? disputeId, String? dueAt, List<String>? evidenceIds, String? reportedAt, String? reportedDate})
Dispute.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
brandDisputeId → String?
final
cardBrand → String?
final
createdAt → String?
final
disputedPayment → DisputedPayment?
final
disputeId → String?
final
dueAt → String?
final
evidenceIds → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
reason → DisputeReason?
final
reportedAt → String?
final
reportedDate → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → DisputeState?
final
updatedAt → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited