DisputeEvidence class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

DisputeEvidence({String? id, String? disputeId, DisputeEvidenceFile? evidenceFile, String? evidenceId, DisputeEvidenceType? evidenceType, String? evidenceText, String? uploadedAt})
DisputeEvidence.fromJson(Map<String, dynamic> json)
factory

Properties

disputeId → String?
final
evidenceFile → DisputeEvidenceFile?
final
evidenceId → String?
final
evidenceText → String?
final
evidenceType → DisputeEvidenceType?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited