ExternalPaymentDetails class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ExternalPaymentDetails({ExternalPaymentType? type, String? source, Money? sourceFeeMoney, String? sourceId})
ExternalPaymentDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
final
sourceFeeMoney → Money?
final
sourceId → String?
final
type → ExternalPaymentType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited