GiftCard class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

GiftCard({GiftCardStatus? status, String? id, String? createdAt, List<String>? customerIds, GiftCardType? type, Money? balanceMoney, String? gan, GiftCardGANSource? ganSource})
GiftCard.fromJson(Map<String, dynamic> json)
factory

Properties

balanceMoney → Money?
final
createdAt → String?
final
customerIds → List<String>?
final
gan → String?
final
ganSource → GiftCardGANSource?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → GiftCardStatus?
final
type → GiftCardType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited