GiftCardActivityRedeem class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

GiftCardActivityRedeem({Money? amountMoney, String? referenceId, String? paymentId})
GiftCardActivityRedeem.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
paymentId → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited