InventoryAdjustment class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InventoryAdjustment({String? locationId, String? id, String? createdAt, SourceApplication? source, Money? totalPriceMoney, String? catalogObjectId, String? referenceId, String? quantity, String? transactionId, String? refundId, String? employeeId, InventoryAdjustmentGroup? adjustmentGroup, String? catalogObjectType, String? fromState, String? goodsReceiptId, String? occurredAt, String? purchaseOrderId, String? toState})
InventoryAdjustment.fromJson(Map<String, dynamic> json)
factory

Properties

adjustmentGroup → InventoryAdjustmentGroup?
final
catalogObjectId → String?
final
catalogObjectType → String?
final
createdAt → String?
final
employeeId → String?
final
fromState → String?
final
goodsReceiptId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
occurredAt → String?
final
purchaseOrderId → String?
final
quantity → String?
final
referenceId → String?
final
refundId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → SourceApplication?
final
toState → String?
final
totalPriceMoney → Money?
final
transactionId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited