InventoryChange class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InventoryChange({InventoryChangeType? type, String? measurementUnitId, CatalogMeasurementUnit? measurementUnit, InventoryAdjustment? adjustment, InventoryPhysicalCount? physicalCount, InventoryTransfer? transfer})
InventoryChange.fromJson(Map<String, dynamic> json)
factory

Properties

adjustment → InventoryAdjustment?
final
hashCode → int
The hash code for this object.
no setterinherited
measurementUnit → CatalogMeasurementUnit?
final
measurementUnitId → String?
final
physicalCount → InventoryPhysicalCount?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transfer → InventoryTransfer?
final
type → InventoryChangeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited