InventoryCount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InventoryCount({String? locationId, InventoryState? state, String? catalogObjectType, String? quantity, String? catalogObjectId, String? calculatedAt, bool? isEstimated})
InventoryCount.fromJson(Map<String, dynamic> json)
factory

Properties

calculatedAt → String?
final
catalogObjectId → String?
final
catalogObjectType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isEstimated → bool?
final
locationId → String?
final
quantity → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → InventoryState?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited