InventoryPhysicalCount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InventoryPhysicalCount({String? id, String? occurredAt, String? catalogObjectType, String? employeeId, String? quantity, String? referenceId, String? catalogObjectId, SourceApplication? source, String? createdAt, String? locationId, InventoryState? state})
InventoryPhysicalCount.fromJson(Map<String, dynamic> json)
factory

Properties

catalogObjectId → String?
final
catalogObjectType → String?
final
createdAt → String?
final
employeeId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
occurredAt → String?
final
quantity → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → SourceApplication?
final
state → InventoryState?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited