InventoryResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InventoryResponse({List<SquareError>? errors, List<InventoryCount>? counts, List<InventoryChange>? changes, String? cursor, InventoryCount? count})
InventoryResponse.fromJson(Map<String, dynamic> json)
factory

Properties

changes → List<InventoryChange>?
final
count → InventoryCount?
final
counts → List<InventoryCount>?
final
cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited