Invoice class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Invoice({String? orderId, int? version, String? locationId, String? id, String? timezone, String? createdAt, InvoiceStatus? status, String? description, String? updatedAt, String? title, InvoiceAcceptedPaymentMethods? acceptedPaymentMethods, List<InvoiceCustomField>? customFields, String? deliveryMethod, String? invoiceNumber, Money? nextPaymentAmountMoney, String? paymentConditions, List<InvoicePaymentRequest>? paymentRequests, InvoiceRecipient? primaryRecipient, String? publicUrl, String? saleOrServiceDate, String? scheduledAt, String? subscriptionId})
Invoice.fromJson(Map<String, dynamic> json)
factory

Properties

acceptedPaymentMethods → InvoiceAcceptedPaymentMethods?
final
createdAt → String?
final
customFields → List<InvoiceCustomField>?
final
deliveryMethod → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
invoiceNumber → String?
final
locationId → String?
final
nextPaymentAmountMoney → Money?
final
orderId → String?
final
paymentConditions → String?
final
paymentRequests → List<InvoicePaymentRequest>?
final
primaryRecipient → InvoiceRecipient?
final
publicUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleOrServiceDate → String?
final
scheduledAt → String?
final
status → InvoiceStatus?
final
subscriptionId → String?
final
timezone → String?
final
title → String?
final
updatedAt → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited