InvoiceCustomField class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InvoiceCustomField({String? value, String? label, InvoiceCustomFieldPlacement? placement})
InvoiceCustomField.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
placement → InvoiceCustomFieldPlacement?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited