InvoicePaymentReminder class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InvoicePaymentReminder({String? uid, InvoicePaymentReminderStatus? status, String? message, int? relativeScheduledDays, String? sentAt})
InvoicePaymentReminder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
relativeScheduledDays → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentAt → String?
final
status → InvoicePaymentReminderStatus?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited