InvoicePaymentRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InvoicePaymentRequest({String? cardId, String? uid, String? dueDate, InvoiceAutomaticPaymentSource? automaticPaymentSource, Money? computedAmountMoney, Money? fixedAmountRequestedMoney, String? percentageRequested, List<InvoicePaymentReminder>? reminders, InvoiceRequestMethod? requestMethod, InvoiceRequestType? requestType, Money? roundingAdjustmentIncludedMoney, bool? tippingEnabled, Money? totalCompletedAmountMoney})
InvoicePaymentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

automaticPaymentSource → InvoiceAutomaticPaymentSource?
final
cardId → String?
final
computedAmountMoney → Money?
final
dueDate → String?
final
fixedAmountRequestedMoney → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
percentageRequested → String?
final
reminders → List<InvoicePaymentReminder>?
final
requestMethod → InvoiceRequestMethod?
final
requestType → InvoiceRequestType?
final
roundingAdjustmentIncludedMoney → Money?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tippingEnabled → bool?
final
totalCompletedAmountMoney → Money?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited