InvoiceRecipient class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

InvoiceRecipient({String? customerId, String? emailAddress, Address? address, String? phoneNumber, String? companyName, String? givenName, String? familyName, InvoiceRecipientTaxIds? taxIds})
InvoiceRecipient.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
companyName → String?
final
customerId → String?
final
emailAddress → String?
final
familyName → String?
final
givenName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxIds → InvoiceRecipientTaxIds?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited