ItemVariationLocationOverrides class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ItemVariationLocationOverrides({bool? trackInventory, CatalogPricingType? pricingType, InventoryAlertType? inventoryAlertType, int? inventoryAlertThreshold, Money? priceMoney, String? locationId})
ItemVariationLocationOverrides.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inventoryAlertThreshold → int?
final
inventoryAlertType → InventoryAlertType?
final
locationId → String?
final
priceMoney → Money?
final
pricingType → CatalogPricingType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackInventory → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited