JobAssignment class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

JobAssignment({Money? hourlyRate, Money? annualRate, String? jobTitle, JobAssignmentPayType? payType, int? weeklyHours})
JobAssignment.fromJson(Map<String, dynamic> json)
factory

Properties

annualRate → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
hourlyRate → Money?
final
jobTitle → String?
final
payType → JobAssignmentPayType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weeklyHours → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited