Location class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Location({String? businessName, String? currency, String? country, String? languageCode, String? id, LocationStatus? status, String? createdAt, String? description, LocationType? type, String? name, String? phoneNumber, Address? address, TaxIds? taxIds, String? timezone, String? merchantId, String? businessEmail, BusinessHours? businessHours, List<LocationCapability>? capabilities, SquareCoordinates? coordinates, String? facebookUrl, String? fullFormatLogoUrl, String? instagramUsername, String? logoUrl, String? mcc, String? posBackgroundUrl, String? twitterUsername, String? websiteUrl})
Location.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
businessEmail → String?
final
businessHours → BusinessHours?
final
businessName → String?
final
capabilities → List<LocationCapability>?
final
coordinates → SquareCoordinates?
final
country → String?
final
createdAt → String?
final
currency → String?
final
description → String?
final
facebookUrl → String?
final
fullFormatLogoUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
instagramUsername → String?
final
languageCode → String?
final
logoUrl → String?
final
mcc → String?
final
merchantId → String?
final
name → String?
final
phoneNumber → String?
final
posBackgroundUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → LocationStatus?
final
taxIds → TaxIds?
final
timezone → String?
final
twitterUsername → String?
final
type → LocationType?
final
websiteUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited