LoyaltyAccount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LoyaltyAccount({String? updatedAt, String? createdAt, String? id, String? customerId, int? balance, String? enrolledAt, List<LoyaltyAccountExpiringPointDeadline>? expiringPointDeadlines, int? lifetimePoints, LoyaltyAccountMapping? mapping, String? programId})
LoyaltyAccount.fromJson(Map<String, dynamic> json)
factory

Properties

balance → int?
final
createdAt → String?
final
customerId → String?
final
enrolledAt → String?
final
expiringPointDeadlines → List<LoyaltyAccountExpiringPointDeadline>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
lifetimePoints → int?
final
mapping → LoyaltyAccountMapping?
final
programId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited