LoyaltyEventFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LoyaltyEventFilter({LoyaltyEventDateTimeFilter? dateTimeFilter, LoyaltyEventLocationFilter? locationFilter, LoyaltyEventLoyaltyAccountFilter? loyaltyAccountFilter, LoyaltyEventOrderFilter? orderFilter, LoyaltyEventTypeFilter? typeFilter})
LoyaltyEventFilter.fromJson(Map<String, dynamic> json)
factory

Properties

dateTimeFilter → LoyaltyEventDateTimeFilter?
final
hashCode → int
The hash code for this object.
no setterinherited
locationFilter → LoyaltyEventLocationFilter?
final
loyaltyAccountFilter → LoyaltyEventLoyaltyAccountFilter?
final
orderFilter → LoyaltyEventOrderFilter?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeFilter → LoyaltyEventTypeFilter?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited