LoyaltyProgram class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LoyaltyProgram({String? createdAt, String? id, String? updatedAt, List<String>? locationIds, LoyaltyProgramStatus? status, List<LoyaltyProgramAccrualRule>? accrualRules, LoyaltyProgramExpirationPolicy? expirationPolicy, List<LoyaltyProgramRewardTier>? rewardTiers, LoyaltyProgramTerminology? terminology})
LoyaltyProgram.fromJson(Map<String, dynamic> json)
factory

Properties

accrualRules → List<LoyaltyProgramAccrualRule>?
final
createdAt → String?
final
expirationPolicy → LoyaltyProgramExpirationPolicy?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationIds → List<String>?
final
rewardTiers → List<LoyaltyProgramRewardTier>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → LoyaltyProgramStatus?
final
terminology → LoyaltyProgramTerminology?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited