LoyaltyProgramRewardDefinition class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LoyaltyProgramRewardDefinition({LoyaltyProgramRewardDefinitionType? discountType, LoyaltyProgramRewardDefinitionScope? scope, List<String>? catalogObjectIds, Money? fixedDiscountMoney, Money? maxDiscountMoney, String? percentageDiscount})
LoyaltyProgramRewardDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

catalogObjectIds → List<String>?
final
discountType → LoyaltyProgramRewardDefinitionType?
final
fixedDiscountMoney → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
maxDiscountMoney → Money?
final
percentageDiscount → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → LoyaltyProgramRewardDefinitionScope?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited