LoyaltyReward class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LoyaltyReward({int? points, String? createdAt, String? id, LoyaltyRewardStatus? status, String? updatedAt, String? orderId, String? rewardTierId, String? loyaltyAccountId, String? redeemedAt})
LoyaltyReward.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
loyaltyAccountId → String?
final
orderId → String?
final
points → int?
final
redeemedAt → String?
final
rewardTierId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → LoyaltyRewardStatus?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited