Merchant class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Merchant({String? createdAt, MerchantStatus? status, String? id, String? languageCode, String? country, String? currency, String? businessName, String? mainLocationId})
Merchant.fromJson(Map<String, dynamic> json)
factory

Properties

businessName → String?
final
country → String?
final
createdAt → String?
final
currency → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
languageCode → String?
final
mainLocationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → MerchantStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited