OrderFulfillmentRecipient class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderFulfillmentRecipient({String? customerId, String? phoneNumber, Address? address, String? displayName, String? emailAddress})
OrderFulfillmentRecipient.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
customerId → String?
final
displayName → String?
final
emailAddress → String?
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited