OrderLineItemDiscount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderLineItemDiscount({int? catalogVersion, String? catalogObjectId, String? name, String? uid, Map<String, String>? metadata, OrderLineItemDiscountScope? scope, String? type, Money? amountMoney, Money? appliedMoney, String? percentage, String? pricingRuleId, List<String>? rewardIds})
OrderLineItemDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appliedMoney → Money?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, String>?
final
name → String?
final
percentage → String?
final
pricingRuleId → String?
final
rewardIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → OrderLineItemDiscountScope?
final
type → String?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited