OrderLineItemModifier class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderLineItemModifier({String? name, int? catalogVersion, String? catalogObjectId, String? uid, Money? basePriceMoney, Money? totalPriceMoney})
OrderLineItemModifier.fromJson(Map<String, dynamic> json)
factory

Properties

basePriceMoney → Money?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPriceMoney → Money?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited