OrderLineItemPricingBlocklistsBlockedDiscount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderLineItemPricingBlocklistsBlockedDiscount({String? uid, String? discountUid, String? discountCatalogObjectId})
OrderLineItemPricingBlocklistsBlockedDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

discountCatalogObjectId → String?
final
discountUid → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited