OrderLineItemTax class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderLineItemTax({String? percentage, Money? appliedMoney, String? type, OrderLineItemTaxScope? scope, Map<String, String>? metadata, String? uid, String? name, String? catalogObjectId, int? catalogVersion, bool? autoApplied})
OrderLineItemTax.fromJson(Map<String, dynamic> json)
factory

Properties

appliedMoney → Money?
final
autoApplied → bool?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, String>?
final
name → String?
final
percentage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → OrderLineItemTaxScope?
final
type → String?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited