OrderResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderResponse({List<SquareError>? errors, Order? order, List<Order>? orders, String? cursor, OrderEntry? orderEntries})
OrderResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
order → Order?
final
orderEntries → OrderEntry?
final
orders → List<Order>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited