OrderReturn class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderReturn({OrderRoundingAdjustment? roundingAdjustment, OrderMoneyAmounts? returnAmounts, List<OrderReturnDiscount>? returnDiscounts, List<OrderReturnLineItem>? returnLineItems, List<OrderReturnServiceCharge>? returnServiceCharges, List<OrderReturnTax>? returnTaxes, String? sourceOrderId, String? uid})
OrderReturn.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
returnAmounts → OrderMoneyAmounts?
final
returnDiscounts → List<OrderReturnDiscount>?
final
returnLineItems → List<OrderReturnLineItem>?
final
returnServiceCharges → List<OrderReturnServiceCharge>?
final
returnTaxes → List<OrderReturnTax>?
final
roundingAdjustment → OrderRoundingAdjustment?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceOrderId → String?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited