OrderReturnDiscount class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderReturnDiscount({Money? amountMoney, String? name, OrderLineItemDiscountType? type, int? catalogVersion, String? catalogObjectId, String? uid, Money? appliedMoney, String? percentage, OrderLineItemDiscountScope? scope, String? sourceDiscountUid})
OrderReturnDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appliedMoney → Money?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
percentage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → OrderLineItemDiscountScope?
final
sourceDiscountUid → String?
final
type → OrderLineItemDiscountType?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited