OrderReturnServiceCharge class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderReturnServiceCharge({Money? totalMoney, Money? appliedTaxes, Money? totalTaxMoney, String? name, int? catalogVersion, String? catalogObjectId, String? uid, String? percentage, Money? appliedMoney, Money? amountMoney, String? calculationPhase, bool? taxable, String? sourceServiceChargeUid})
OrderReturnServiceCharge.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appliedMoney → Money?
final
appliedTaxes → Money?
final
calculationPhase → String?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
percentage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceServiceChargeUid → String?
final
taxable → bool?
final
totalMoney → Money?
final
totalTaxMoney → Money?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited