OrderReturnTax class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderReturnTax({Money? appliedMoney, String? percentage, String? uid, String? catalogObjectId, int? catalogVersion, String? name, OrderLineItemTaxScope? scope, OrderLineItemTaxType? type, String? sourceTaxUid})
OrderReturnTax.fromJson(Map<String, dynamic> json)
factory

Properties

appliedMoney → Money?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
percentage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → OrderLineItemTaxScope?
final
sourceTaxUid → String?
final
type → OrderLineItemTaxType?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited