OrderServiceCharge class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

OrderServiceCharge({String? name, Money? amountMoney, String? uid, Money? totalMoney, String? type, Map<String, String>? metadata, int? catalogVersion, String? catalogObjectId, String? appliedMoney, String? percentage, List<OrderLineItemAppliedTax>? appliedTaxes, Money? totalTaxMoney, bool? taxable, String? calculationPhase})
OrderServiceCharge.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appliedMoney → String?
final
appliedTaxes → List<OrderLineItemAppliedTax>?
final
calculationPhase → String?
final
catalogObjectId → String?
final
catalogVersion → int?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, String>?
final
name → String?
final
percentage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxable → bool?
final
totalMoney → Money?
final
totalTaxMoney → Money?
final
type → String?
final
uid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited