Payment class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Payment({String? createdAt, String? id, String? updatedAt, String? locationId, String? teamMemberId, String? customerId, String? orderId, Money? amountMoney, String? note, String? referenceId, String? employeeId, List<String>? capabilities, Address? billingAddress, Money? totalMoney, CashPaymentDetails? cashDetails, CardPaymentDetails? cardDetails, Money? tipMoney, Money? appFeeMoney, ApplicationDetails? applicationDetails, Money? approvedMoney, BankAccountPaymentDetails? bankAccountDetails, String? buyerEmailAddress, String? delayAction, String? delayDuration, String? delayedUntil, DeviceDetails? deviceDetails, ExternalPaymentDetails? externalDetails, Address? shippingAddress, List<ProcessingFee>? processingFee, String? receiptNumber, String? receiptUrl, Money? refundedMoney, List<String>? refundIds, RiskEvaluation? riskEvaluation, PaymentSourceType? sourceType, String? statementDescriptionIdentifier, String? versionToken, DigitalWalletDetails? walletDetails})
Payment.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appFeeMoney → Money?
final
applicationDetails → ApplicationDetails?
final
approvedMoney → Money?
final
bankAccountDetails → BankAccountPaymentDetails?
final
billingAddress → Address?
final
buyerEmailAddress → String?
final
capabilities → List<String>?
final
cardDetails → CardPaymentDetails?
final
cashDetails → CashPaymentDetails?
final
createdAt → String?
final
customerId → String?
final
delayAction → String?
final
delayDuration → String?
final
delayedUntil → String?
final
deviceDetails → DeviceDetails?
final
employeeId → String?
final
externalDetails → ExternalPaymentDetails?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
note → String?
final
orderId → String?
final
processingFee → List<ProcessingFee>?
final
receiptNumber → String?
final
receiptUrl → String?
final
referenceId → String?
final
refundedMoney → Money?
final
refundIds → List<String>?
final
riskEvaluation → RiskEvaluation?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress → Address?
final
sourceType → PaymentSourceType?
final
statementDescriptionIdentifier → String?
final
teamMemberId → String?
final
tipMoney → Money?
final
totalMoney → Money?
final
updatedAt → String?
final
versionToken → String?
final
walletDetails → DigitalWalletDetails?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited