ProcessingFee class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ProcessingFee({Money? amountMoney, ProcessingFeeType? type, String? effectiveAt})
ProcessingFee.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
effectiveAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ProcessingFeeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited