Refund class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Refund({Money? amountMoney, String? locationId, String? createdAt, String? id, RefundStatus? status, String? transactionId, List<AdditionalRecipient>? additionalRecipients, Money? processingFeeMoney, String? reason, String? tenderId})
Refund.fromJson(Map<String, dynamic> json)
factory

Properties

additionalRecipients → List<AdditionalRecipient>?
final
amountMoney → Money?
final
createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
processingFeeMoney → Money?
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → RefundStatus?
final
tenderId → String?
final
transactionId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited