RefundPaymentRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

RefundPaymentRequest({required String idempotencyKey, String? teamMemberId, Money? appFeeMoney, required Money amountMoney, String? reason, String? paymentId, String? paymentVersionToken})
RefundPaymentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money
final
appFeeMoney → Money?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
paymentId → String?
final
paymentVersionToken → String?
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamMemberId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited