SearchAvailabilityFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SearchAvailabilityFilter({String? locationId, String? bookingId, List<SegmentFilter>? segmentFilters, TimeRange? startAtRange})
SearchAvailabilityFilter.fromJson(Map<String, dynamic> json)
factory

Properties

bookingId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
locationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentFilters → List<SegmentFilter>?
final
startAtRange → TimeRange?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited