SearchSubscriptionRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SearchSubscriptionRequest({String? cursor, SearchSubscriptionsQuery? query, int? limit, List<String>? include})
SearchSubscriptionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
final
hashCode → int
The hash code for this object.
no setterinherited
include → List<String>?
final
limit → int?
final
query → SearchSubscriptionsQuery?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited