SearchSubscriptionsFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SearchSubscriptionsFilter({List<String>? customerIds, List<String>? locationIds, List<String>? sourceNames})
SearchSubscriptionsFilter.fromJson(Map<String, dynamic> json)
factory

Properties

customerIds → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
locationIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNames → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited