SearchTeamMembersFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SearchTeamMembersFilter({bool? isOwner, TeamMemberStatus? status, List<String>? locationIds})
SearchTeamMembersFilter.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOwner → bool?
final
locationIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TeamMemberStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited