Shift class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Shift({int? version, String? locationId, String? createdAt, String? id, String? updatedAt, ShiftStatus? status, String? employeeId, String? timezone, String? teamMemberId, String? startAt, String? endAt, List<Break>? breaks, ShiftWage? wage})
Shift.fromJson(Map<String, dynamic> json)
factory

Properties

breaks → List<Break>?
final
createdAt → String?
final
employeeId → String?
final
endAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → String?
final
status → ShiftStatus?
final
teamMemberId → String?
final
timezone → String?
final
updatedAt → String?
final
version → int?
final
wage → ShiftWage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited