ShiftFilter class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ShiftFilter({required List<String> locationIds, ShiftStatus? status, required List<String> teamMemberIds, List<String>? employeeIds, TimeRange? end, TimeRange? start, ShiftWorkday? workday})
ShiftFilter.fromJson(Map<String, dynamic> json)
factory

Properties

employeeIds → List<String>?
final
end → TimeRange?
final
hashCode → int
The hash code for this object.
no setterinherited
locationIds → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TimeRange?
final
status → ShiftStatus?
final
teamMemberIds → List<String>
final
workday → ShiftWorkday?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited