Site class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Site({String? id, String? createdAt, String? updatedAt, String? domain, bool? isPublished, String? siteTitle})
Site.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
domain → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isPublished → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteTitle → String?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited