SquareError class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SquareError({String? category, SquareErrorCode? code, String? detail, String? field})
SquareError.fromJson(Map<String, dynamic> json)
factory

Properties

category → String?
final
code → SquareErrorCode?
final
detail → String?
final
field → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited