SquarePaymentResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SquarePaymentResponse({List<SquareError>? errors, String? cursor, Payment? payment, List<Payment>? payments})
SquarePaymentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
payment → Payment?
final
payments → List<Payment>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited