StandardUnitDescription class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

StandardUnitDescription({String? name, String? abbreviation, MeasurementUnit? unit})
StandardUnitDescription.fromJson(Map<String, dynamic> json)
factory

Properties

abbreviation → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → MeasurementUnit?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited