SubscriptionResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SubscriptionResponse({List<SquareError>? errors, List<Subscription>? subscriptions, Subscription? subscription, String? cursor, List<SubscriptionAction>? actions})
SubscriptionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<SubscriptionAction>?
final
cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → Subscription?
final
subscriptions → List<Subscription>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited