TeamMember class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TeamMember({String? createdAt, String? id, TeamMemberStatus? status, String? phoneNumber, String? updatedAt, String? referenceId, String? emailAddress, String? givenName, String? familyName, TeamMemberAssignedLocations? assignedLocations, bool? is_owner})
TeamMember.fromJson(Map<String, dynamic> json)
factory

Properties

assignedLocations → TeamMemberAssignedLocations?
final
createdAt → String?
final
emailAddress → String?
final
familyName → String?
final
givenName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
is_owner → bool?
final
phoneNumber → String?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TeamMemberStatus?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited