Tender class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Tender({String? type, Money? amountMoney, String? id, Money? processingFeeMoney, List<AdditionalRecipient>? additionalRecipients, String? transactionId, String? createdAt, String? locationId, Money? tipMoney, String? note, String? customerId, String? paymentId, TenderCardDetails? cardDetails, TenderCardDetails? cashDetails})
Tender.fromJson(Map<String, dynamic> json)
factory

Properties

additionalRecipients → List<AdditionalRecipient>?
final
amountMoney → Money?
final
cardDetails → TenderCardDetails?
final
cashDetails → TenderCardDetails?
final
createdAt → String?
final
customerId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
note → String?
final
paymentId → String?
final
processingFeeMoney → Money?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipMoney → Money?
final
transactionId → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited