TerminalCheckout class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TerminalCheckout({String? updatedAt, String? createdAt, String? id, String? referenceId, String? locationId, String? status, String? customerId, Money? amountMoney, String? note, ActionCancelReason? cancelReason, String? appId, String? deadlineDuration, DeviceCheckoutOptions? deviceOptions, List<String>? paymentIds, CheckoutOptionsPaymentType? paymentType})
TerminalCheckout.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appId → String?
final
cancelReason → ActionCancelReason?
final
createdAt → String?
final
customerId → String?
final
deadlineDuration → String?
final
deviceOptions → DeviceCheckoutOptions?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
note → String?
final
paymentIds → List<String>?
final
paymentType → CheckoutOptionsPaymentType?
final
referenceId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited