TerminalRefund class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TerminalRefund({String? createdAt, TerimnalRefundStatus? status, String? deviceId, String? deadlineDuration, String? appId, ActionCancelReason? cancelReason, Money? amountMoney, String? locationId, String? id, String? updatedAt, String? reason, String? orderId, String? paymentId, String? refundId})
TerminalRefund.fromJson(Map<String, dynamic> json)
factory

Properties

amountMoney → Money?
final
appId → String?
final
cancelReason → ActionCancelReason?
final
createdAt → String?
final
deadlineDuration → String?
final
deviceId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locationId → String?
final
orderId → String?
final
paymentId → String?
final
reason → String?
final
refundId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TerimnalRefundStatus?
final
updatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited