TokenResponse class

Responst for the OAuth request

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TokenResponse({String? refreshToken, String? accessToken, int? expiresIn, bool? isShortLived, String? merchantId})
TokenResponse.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken → String?
final
expiresIn → int?
final
hashCode → int
The hash code for this object.
no setterinherited
isShortLived → bool?
final
merchantId → String?
final
refreshToken → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited