UpdateCatalogItemsModifier class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

UpdateCatalogItemsModifier({required List<String> itemIds, List<String>? modifierListsToDisable, List<String>? modifierListsToEnable})
UpdateCatalogItemsModifier.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemIds → List<String>
final
modifierListsToDisable → List<String>?
final
modifierListsToEnable → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited