WageSetting class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

WageSetting({String? teamMemberId, String? createdAt, String? updatedAt, int? version, bool? isOvertimeExempt, List<JobAssignment>? jobAssignments})
WageSetting.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isOvertimeExempt → bool?
final
jobAssignments → List<JobAssignment>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamMemberId → String?
final
updatedAt → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited