WorkWeekConfigResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

WorkWeekConfigResponse({String? cursor, List<SquareError>? errors, WorkweekConfig? workweekConfig, List<WorkweekConfig>? workweekConfigs})
WorkWeekConfigResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
final
errors → List<SquareError>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workweekConfig → WorkweekConfig?
final
workweekConfigs → List<WorkweekConfig>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited